gen_plan_with_matching_schema

Function gen_plan_with_matching_schema 

pub(crate) async fn gen_plan_with_matching_schema(
    sql: &str,
    query_ctx: QueryContextRef,
    engine: QueryEngineRef,
    sink_table_schema: SchemaRef,
    primary_key_indices: &[usize],
    allow_partial: bool,
) -> Result<LogicalPlan, Error>
Generate a plan that matches the schema of the sink table from given sql by alias and adding auto columns