fn find_column_names(expr: &Expr, names: &mut Vec<String>)Expand description
Recursively find all Expr::Column names inside an expression tree.
Only recurses into wrappers that are merge-transparent.
Non-transparent wrappers (e.g., ScalarFunction, Negative, Cast) are
intentionally not recursed into since their merge semantics would be
incorrect.
Cast/TryCast are intentionally opaque: merging already-casted aggregate
outputs is not generally equivalent to casting the final merged aggregate.